-- fichero fdbins.sql
-------------------------------------------------------------------
-- instalacion de una base de datos difusa (fdb, fuzzy database) --
-- creacion de las tablas insercion de algunas tuplas en ellas,  --
-- asi como creacion de elementos en la fmb de esta bd           --
-- (etiquetas...).                                               --
-- para la instalacion no hace falta desinstalarla previamente.  --
-- debe ejecutarse por el usuario que sera propietario de las    --
-- tablas de la bd (no necesariamente un dba).                   --
-------------------------------------------------------------------

\echo ('>>>>');
\echo ('>>>> ****************************************** <<<<');
\echo ('>>>> **** instalacion de una base de datos **** <<<<');
\echo ('>>>> **** difusa de ejemplo.               **** <<<<');
\echo ('>>>> ****************************************** <<<<');
\echo ('>>>>');
\echo ('>>>> notas:');
\echo ('>>>>   - es requisito indispensable que este instalado first (tablas de la fmb...).');
\echo ('>>>>   - no importa si se producen errores al intentar borrar');
\echo ('>>>>   - cualquier otro error podra impedir la correcta consulta a esta bd.');
\echo ('>>>>     en ese caso revise el codigo del error y el lugar donde ha ocurrido.');
\echo ('>>>>');

\echo ('>>>> borrando y creando tabla personal...');
drop   table personal cascade;
create table personal(
  emp char(4) not null,
  nombre char (20) not null,
  sexo char(1) not null,
  edadt numeric(1) default 0 not null
      check (edadt between 0 and 7)
      constraint null_invalido_edad      check (edadt<>2)
      constraint undefined_invalido_edad check (edadt<>1),
  edad1 numeric(3),
  edad2 numeric(3),
  edad3 numeric(3),
  edad4 numeric(3),
  ciudad char(15) not null,
  primary key (emp));

\echo ('>>>> borrando y creando tabla aptitud...');
drop   table aptitud cascade;
create table aptitud(
  emp char(4) not null,
  estudiost numeric(1) default 0 not null
      check (estudiost between 0 and 4),
  estudiosp1 numeric(3,2), -- grado de compatibilidad para la etiqueta siguiente
  estudios1 numeric(3),    -- fuzzy_object_list.fuzzy_id%type
  proft numeric(1) default 0 not null
      check (proft between 0 and 4),
  profp1 numeric(3,2),
  prof1 numeric(3) not null, -- fuzzy_object_list.fuzzy_id%type
  experienciat numeric(1) default 0 not null
      check (experienciat between 0 and 7),
  experiencia1 numeric(2),
  experiencia2 numeric(2),
  experiencia3 numeric(2),
  experiencia4 numeric(2),
  primary key (emp),
  foreign key (emp) references personal on delete cascade);

\echo ('>>>> borrando y creando tabla dpto...');
drop   table dpto cascade;
create table dpto(
  dpto   char(4)  not null,
  nombre  char(20) not null,
  localiz char(15) not null,
  beneficios numeric(10) not null,
  primary key (dpto));

\echo ('>>>> borrando y creando tabla puestos...');
drop   table puestos cascade;
create table puestos(
  puesto char(4) not null,
  nombre char(20) not null,
  estudiost numeric(1) not null
      check (estudiost between 0 and 4),
  estudiosp1 numeric(3,2),
  estudios1 numeric(3) not null,
  proft numeric(1) not null,
      check (proft between 0 and 4),
  profp1 numeric(3,2),
  prof1 numeric(3) not null,
  experienciat numeric(1) not null,
      check (experienciat between 0 and 7),
  experiencia1 numeric(2),
  experiencia2 numeric(2),
  experiencia3 numeric(2),
  experiencia4 numeric(2),
  primary key (puesto));

\echo ('>>>> borrando y creando tabla empleos...');
drop   table empleos;
create table empleos(
  emp char(4) not null,
  dpto char(4) not null,
  puesto char(4) not null,
  sueldo numeric(7) not null,
  comisiont numeric(1) not null,
      check (comisiont between 0 and 7),
  comision1 numeric(7),
  comision2 numeric(7),
  comision3 numeric(7),
  comision4 numeric(7),
  rendimientot numeric(1) not null,
      check (rendimientot between 0 and 4),
  rendimientop1 numeric(3,2),
  rendimiento1 numeric(3) not null,
  primary key (emp,dpto,puesto),
  foreign key (emp) references personal on delete cascade,
  foreign key (emp) references aptitud on delete cascade,
  foreign key (dpto) references dpto on delete cascade,
  foreign key (puesto) references puestos on delete cascade);

\echo ('>>>> borrando y creando tabla ciudades...');
drop   table ciudades;
create table ciudades(
  ciudad1 char(15) not null,
  ciudad2 char(15) not null,
  distancia numeric(5) not null,
  primary key (ciudad1,ciudad2));

\echo ('>>>> borrando y creando tabla requisitos...');
-- requisitos buscados en ofertas de empleo (len=4)


drop   table requisitos;
create table requisitos(
  clave      integer   not null,
  estudiost  numeric(1) not null,
      check (estudiost between 0 and 4),
  estudiosp1 numeric(3,2),
  estudios1  numeric(3),
  estudiosp2 numeric(3,2),
  estudios2  numeric(3),
  estudiosp3 numeric(3,2),
  estudios3  numeric(3),
  estudiosp4 numeric(3,2),
  estudios4  numeric(3),
  primary key (clave));

drop function ejemplo();
create function ejemplo() 
returns integer as '
declare
  t_aptitud     numeric;
  t_empleos     numeric;
  t_puestos     numeric;
  t_ciudades   numeric;
  t_dpto       numeric;
  t_personal   numeric;
  t_requisitos numeric;
  c_req_estudios numeric;
  c_estudios     numeric;
  c_experiencia  numeric;
  c_prof         numeric;
  c_comision     numeric;
  c_rendimiento  numeric;
  c_sueldo       numeric;
  c_estudios1    numeric;
  c_experiencia1 numeric;
  c_prof1        numeric;
  c_distancia    numeric;
  c_beneficios   numeric;
  c_edad         numeric;

begin

-- (>>>> insertando valores en la fmb sobre esta bd difusa...);

  -- calcular obj para las tablas con columnas difusas:
  select into t_aptitud relfilenode from pg_class where relname=''aptitud'';
  select into t_empleos relfilenode from pg_class where relname=''empleos'';
  select into t_puestos relfilenode  from pg_class where relname=''puestos'';
  select into t_ciudades relfilenode from pg_class where relname=''ciudades'';
  select into t_dpto relfilenode from pg_class where relname=''dpto'';
  select into t_personal relfilenode from pg_class where relname=''personal'';
  select into t_requisitos relfilenode from pg_class where relname=''requisitos'';

  -- calcular col de las columnas difusas:
  select into c_estudios attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''aptitud'' and 
         a.attrelid = b.relid and 
         a.attname = ''estudiost'';

  select into c_experiencia attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''aptitud'' and 
         a.attrelid = b.relid and 
         a.attname = ''experienciat'';

   select into c_prof attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''aptitud'' and 
         a.attrelid = b.relid and 
         a.attname = ''proft'';

   select into c_comision attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''empleos'' and 
         a.attrelid = b.relid and 
         a.attname = ''comisiont'';

    select into c_rendimiento attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''empleos'' and 
         a.attrelid = b.relid and 
         a.attname = ''rendimientot'';

    select into c_sueldo attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''empleos'' and 
         a.attrelid = b.relid and 
         a.attname = ''sueldo'';

    select into c_estudios1 attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''puestos'' and 
         a.attrelid = b.relid and 
         a.attname = ''estudiost'';

    select into c_experiencia1 attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''puestos'' and 
         a.attrelid = b.relid and 
         a.attname = ''experienciat'';

    select into c_prof1 attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''puestos'' and 
         a.attrelid = b.relid and 
         a.attname = ''proft'';  

    select into c_distancia attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''ciudades'' and 
         a.attrelid = b.relid and 
         a.attname = ''distancia'';  

    select into c_beneficios attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''dpto'' and 
         a.attrelid = b.relid and 
         a.attname = ''beneficios'';  
 
    select into c_beneficios attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''dpto'' and 
         a.attrelid = b.relid and 
         a.attname = ''beneficios'';   
    
    select into c_edad attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''personal'' and 
         a.attrelid = b.relid and 
         a.attname = ''edadt'';  
   
    select into c_req_estudios attnum
    from pg_attribute a, pg_statio_user_tables b
    where 
         b.relname = ''requisitos'' and 
         a.attrelid = b.relid and 
         a.attname = ''estudiost'';  



  -- atributos con tratamiento difuso: tipos 1, 2 o 3
  insert into  fuzzy_col_list   
         values (t_aptitud,c_estudios,3,1, ''public''||''.aptitud.estudios'');
  insert into  fuzzy_col_list  
	 values (t_aptitud,c_experiencia,2,1,''public''||''.aptitud.experiencia'');
  insert into  fuzzy_col_list   
	 values (t_aptitud,c_prof,3,1,''public''||''.aptitud.prof'');
  insert into  fuzzy_col_list   
	 values (t_empleos,c_comision,2,1,''public''||''.empleos.comision'');
  insert into  fuzzy_col_list  
	 values (t_empleos,c_rendimiento,3,1,''public''||''.empleos.rendimiento'');
  insert into  fuzzy_col_list   
	 values (t_empleos,c_sueldo,1,1,''public''||''.empleos.sueldo'');
  insert into  fuzzy_col_list   
	 values (t_puestos,c_estudios1,3,1,''public''||''.puestos.estudios'');
  insert into  fuzzy_col_list   
         values (t_puestos,c_experiencia1,2,1,''public''||''.puestos.experiencia'');
  insert into  fuzzy_col_list  
	 values (t_puestos,c_prof1,3,1,''public''||''.puestos.prof'');
  insert into  fuzzy_col_list   
         values (t_ciudades,c_distancia,1,1,''public''||''.ciudades.distancia'');
  insert into  fuzzy_col_list  
         values (t_dpto,c_beneficios,1,1,''public''||''.dpto.beneficios'');
  insert into  fuzzy_col_list   
         values (t_personal,c_edad,2,1,''public''||''.personal.edad'');
  insert into  fuzzy_col_list   
	 values (t_requisitos,c_req_estudios,3,4,''public''||''.requisitos.estudios''); -- len=4

  -- compatibilidad de atributos tipo 3:
  -- el campo estudios de la tabla requisitos es compatible con
  -- el campo estudios de la tabla aptitud (puede tomar el valor de sus mismas etiquetas)
  insert into fuzzy_compatible_col 
	 values (t_requisitos,c_req_estudios,t_aptitud,c_estudios);
  -- campo puestos.estudios es compatible con aptitud.estudios
  insert into fuzzy_compatible_col 
	 values (t_puestos,c_estudios1,t_aptitud,c_estudios);
  -- campo puestos.prof es compatible con aptitud.prof
  insert into fuzzy_compatible_col  
	 values (t_puestos,c_prof1,t_aptitud,c_prof);

  -- objetos para la tabla empleos:
  insert into fuzzy_object_list  values (t_empleos,c_sueldo,0,''bajo'',0);
  insert into fuzzy_object_list  values (t_empleos,c_sueldo,1,''medio'',0);
  insert into fuzzy_object_list  values (t_empleos,c_sueldo,2,''alto'',0);
  insert into fuzzy_object_list  values (t_empleos,c_sueldo,3,''muy_alto'',0);
  insert into fuzzy_object_list  values (t_empleos,c_comision,0,''reducida'',0);
  insert into fuzzy_object_list  values (t_empleos,c_comision,1,''baja'',0);
  insert into fuzzy_object_list  values (t_empleos,c_comision,2,''normal'',0);
  insert into fuzzy_object_list  values (t_empleos,c_comision,3,''alta'',0);
  insert into fuzzy_object_list  values (t_empleos,c_comision,4,''elevada'',0);
  insert into fuzzy_object_list  values (t_empleos,c_rendimiento,0,''malo'',1);
  insert into fuzzy_object_list  values (t_empleos,c_rendimiento,1,''regular'',1);
  insert into fuzzy_object_list  values (t_empleos,c_rendimiento,2,''bueno'',1);
  insert into fuzzy_object_list  values (t_empleos,c_rendimiento,3,''excelente'',1);

  -- objetos para la tabla aptitud:
  insert into fuzzy_object_list  values(t_aptitud,c_estudios,0,''secundaria'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_estudios,1,''diplomado'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_estudios,2,''licenciado'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_estudios,3,''doctor'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_prof,0,''director'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_prof,1,''ingeniero'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_prof,2,''tecnico'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_prof,3,''administrativo'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_prof,4,''secretario'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_prof,5,''vendedor'',1);
  insert into fuzzy_object_list  values(t_aptitud,c_experiencia,0,''poca'',0);
  insert into fuzzy_object_list  values(t_aptitud,c_experiencia,1,''alguna'',0);
  insert into fuzzy_object_list  values(t_aptitud,c_experiencia,2,''mucha'',0);
  insert into fuzzy_object_list  values(t_aptitud,c_experiencia,3,''bastante'',0);
  insert into fuzzy_object_list  values(t_aptitud,c_experiencia,4,''grande'',0);

  -- objetos para la tabla puestos:
  insert into fuzzy_object_list  values(t_puestos,c_experiencia1,0,''poca'',0);
  insert into fuzzy_object_list  values(t_puestos,c_experiencia1,1,''alguna'',0);
  insert into fuzzy_object_list  values(t_puestos,c_experiencia1,2,''mucha'',0);
  insert into fuzzy_object_list  values(t_puestos,c_experiencia1,3,''bastante'',0);
  insert into fuzzy_object_list  values(t_puestos,c_experiencia1,4,''grande'',0);

  -- objetos para la tabla dpto:
  insert into fuzzy_object_list  values(t_dpto,c_beneficios,0,''escasos'',0);
  insert into fuzzy_object_list  values(t_dpto,c_beneficios,1,''pocos'',0);
  insert into fuzzy_object_list  values(t_dpto,c_beneficios,2,''moderados'',0);
  insert into fuzzy_object_list  values(t_dpto,c_beneficios,3,''elevados'',0);

  -- objetos para la tabla personal:
  insert into fuzzy_object_list  values(t_personal,c_edad,0,''muy_joven'',0);
  insert into fuzzy_object_list  values(t_personal,c_edad,1,''joven'',0);
  insert into fuzzy_object_list  values(t_personal,c_edad,2,''maduro'',0);
  insert into fuzzy_object_list  values(t_personal,c_edad,3,''mayor'',0);
  insert into fuzzy_object_list  values(t_personal,c_edad,4,''muy_mayor'',0);

  -- objetos para la tabla ciudades:
  insert into fuzzy_object_list  values(t_ciudades,c_distancia,0,''muy_corta'',0);
  insert into fuzzy_object_list  values(t_ciudades,c_distancia,1,''corta'',0);
  insert into fuzzy_object_list  values(t_ciudades,c_distancia,2,''media'',0);
  insert into fuzzy_object_list  values(t_ciudades,c_distancia,3,''larga'',0);
  insert into fuzzy_object_list  values(t_ciudades,c_distancia,4,''muy_larga'',0);
  insert into fuzzy_object_list  values(t_ciudades,c_distancia,5,''la_mayor'',0);

  -- definicion de las etiquetas linguisticas:
  insert into fuzzy_label_def values(t_personal,c_edad,0,16,16,20,26);
  insert into fuzzy_label_def values(t_personal,c_edad,1,18,22,30,35);
  insert into fuzzy_label_def values(t_personal,c_edad,2,25,32,45,50);
  insert into fuzzy_label_def values(t_personal,c_edad,3,40,45,55,60);
  insert into fuzzy_label_def values(t_personal,c_edad,4,50,55,62,70);
  insert into fuzzy_label_def values(t_puestos,c_experiencia1,0,0,1,2,4); 
  insert into fuzzy_label_def values(t_puestos,c_experiencia1,1,2,3,5,6);
  insert into fuzzy_label_def values(t_puestos,c_experiencia1,2,5,7,10,12);
  insert into fuzzy_label_def values(t_puestos,c_experiencia1,3,7,8,15,20);
  insert into fuzzy_label_def values(t_puestos,c_experiencia1,4,12,15,50,50);
  insert into fuzzy_label_def values(t_aptitud,c_experiencia,0,0,1,2,4);
  insert into fuzzy_label_def values(t_aptitud,c_experiencia,1,2,3,5,6);
  insert into fuzzy_label_def values(t_aptitud,c_experiencia,2,5,7,10,12);
  insert into fuzzy_label_def values(t_aptitud,c_experiencia,3,7,8,15,20);
  insert into fuzzy_label_def values(t_aptitud,c_experiencia,4,12,15,50,50);

  insert into fuzzy_label_def values(t_dpto,c_beneficios,0,0,10000000,20000000,30000000);
  insert into fuzzy_label_def values(t_dpto,c_beneficios,1,15000000,30000000,50000000,70000000);

  insert into fuzzy_label_def values     
         (t_dpto,c_beneficios,2,30000000,45000000,100000000,140000000);
  insert into fuzzy_label_def values
         (t_dpto,c_beneficios,3,70000000,100000000,1000000000,1000000000);

  insert into fuzzy_label_def values(t_empleos,c_sueldo,0,50000,55000,80000,120000);
  insert into fuzzy_label_def values(t_empleos,c_sueldo,1,70000,90000,170000,200000);
  insert into fuzzy_label_def values(t_empleos,c_sueldo,2,160000,180000,250000,300000);
  insert into fuzzy_label_def values(t_empleos,c_sueldo,3,200000,240000,1000000,1000000);
  insert into fuzzy_label_def values(t_empleos,c_comision,0,0,5000,10000,15000);
  insert into fuzzy_label_def values(t_empleos,c_comision,1,11000,15000,20000,30000);
  insert into fuzzy_label_def values(t_empleos,c_comision,2,15000,17000,30000,40000);
  insert into fuzzy_label_def values(t_empleos,c_comision,3,20000,32000,50000,60000);
  insert into fuzzy_label_def values(t_empleos,c_comision,4,40000,50000,200000,300000);

  insert into fuzzy_label_def values(t_ciudades,c_distancia,0,0,0,70,100);
  insert into fuzzy_label_def values(t_ciudades,c_distancia,1,70,100,150,200);
  insert into fuzzy_label_def values(t_ciudades,c_distancia,2,100,150,250,300);
  insert into fuzzy_label_def values(t_ciudades,c_distancia,3,150,200,450,600);
  insert into fuzzy_label_def values(t_ciudades,c_distancia,4,300,400,1000,1500);
  insert into fuzzy_label_def values(t_ciudades,c_distancia,5,1000,1500,99999,99999);

  -- definicion de las relaciones de semejanza:
  insert into fuzzy_nearness_def values(t_aptitud,c_estudios,0,1,.5);
  insert into fuzzy_nearness_def values(t_aptitud,c_estudios,0,2,.2);
  insert into fuzzy_nearness_def values(t_aptitud,c_estudios,0,3,.1);
  insert into fuzzy_nearness_def values(t_aptitud,c_estudios,1,2,.6);
  insert into fuzzy_nearness_def values(t_aptitud,c_estudios,1,3,.3);
  insert into fuzzy_nearness_def values(t_aptitud,c_estudios,2,3,.8);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,0,1,.8);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,0,2,.7);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,0,3,.6);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,0,4,.4);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,0,5,.4);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,1,2,.8);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,1,3,.2);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,1,4,.2);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,1,5,.2);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,2,3,.8);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,2,4,.6);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,2,5,.5);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,3,4,.7);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,3,5,.6);
  insert into fuzzy_nearness_def values(t_aptitud,c_prof,4,5,.6);

  insert into fuzzy_nearness_def values(t_empleos,c_rendimiento,0,1,.8);
  insert into fuzzy_nearness_def values(t_empleos,c_rendimiento,0,2,.5);
  insert into fuzzy_nearness_def values(t_empleos,c_rendimiento,0,3,.1);
  insert into fuzzy_nearness_def values(t_empleos,c_rendimiento,1,2,.7);
  insert into fuzzy_nearness_def values(t_empleos,c_rendimiento,1,3,.5);
  insert into fuzzy_nearness_def values(t_empleos,c_rendimiento,2,3,.8);

  -- def.de:	1) margenes para valores aprox en cada columna y
  --		2) distancia minima para afirmar en los comparadores mgt y mlt.
  insert into fuzzy_approx_much  values(t_personal,c_edad,5,10);
  -- en edad:	1) si decimos "aproximadamente 15 anos", entendemos 15+-5
  -- 2) para que dos edades sean muy diferentes (mgt o mlt), tendran que diferir en 10 anos
  insert into fuzzy_approx_much  values(t_aptitud,c_experiencia,2,5);
  insert into fuzzy_approx_much  values(t_dpto,c_beneficios,10000000,30000000);
  insert into fuzzy_approx_much  values(t_puestos,c_experiencia1,2,5);
  insert into fuzzy_approx_much  values(t_empleos,c_sueldo,10000,50000);
  insert into fuzzy_approx_much  values(t_empleos,c_comision,5000,15000);
  insert into fuzzy_approx_much  values(t_ciudades,c_distancia,25,100);

 -- (>>>> insertando valores en las tablas de esta bd difusa...);
  -- *****  inserciones de los valores de las tablas ***** --
  insert into personal values (''e0'' ,''victor''  ,''v'',4,0,null ,null,null,''barcelona'');
  insert into personal values (''e1'' ,''sixto''   ,''v'',3,17,null ,null,null,''granada'');
  insert into personal values (''e2'' ,''olga''    ,''h'',3,27,null ,null,null,''granada'');
  insert into personal values (''e3'' ,''jose''    ,''v'',5,25,0,0,30,''malaga'');
  insert into personal values (''e4'' ,''salvador'',''v'',7,40,5,-7,55,''valencia'');
  insert into personal values (''e5'' ,''matilde'' ,''h'',6,30,25,35,5,''madrid'');
  insert into personal values (''e6'' ,''ana''     ,''h'',0,23,null,null,null,''barcelona'');
  insert into personal values (''e7'' ,''candido'' ,''v'',3,45,null,null,null,''granada'');
  insert into personal values (''e8'' ,''luis''    ,''v'',3,18,null,null,null,''malaga'');
  insert into personal values (''e9'' ,''federico'',''v'',3,23,null,null,null,''valencia'');
  insert into personal values (''e10'',''alvaro''  ,''v'',4,1,null,null,null,''granada'');
  insert into personal values (''e11'',''eladio''  ,''v'',4,3,null,null,null,''madrid'');
  insert into personal values (''e12'',''carlos''  ,''v'',4,4,null,null,null,''madrid'');
  insert into personal values (''e13'',''cristina'',''h'',4,2,null,null,null,''malaga'');
  insert into personal values (''e14'',''ines''    ,''h'',4,1,null,null,null,''valencia'');
  insert into personal values (''e15'',''julian''  ,''v'',3,31,null,null,null,''barcelona'');
  insert into personal values (''e16'',''antonio'' ,''v'',3,55,null,null,null,''malaga'');
  insert into personal values (''e17'',''silvia''  ,''h'',6,35,30,40,5,''valencia'');
  insert into personal values (''e18'',''paloma''  ,''h'',3,27,null,null,null,''granada'');
  insert into personal values (''e19'',''david yahya'',''v'',4,1,null,null,null,''granada'');
  insert into personal values (''e20'',''paton''   ,''v'',3,60,null,null,null,''castellar'');
  insert into personal values (''e21'',''juanlu''  ,''v'',3,48,null,null,null,''marmolejo'');
  insert into personal values (''e22'',''rafa''    ,''v'',3,17,null,null,null,''jamilena'');
  insert into personal values (''e23'',''d. jose'' ,''v'',3,4,null,null,null,''granada'');
  insert into personal values (''e24'',''patricia'',''h'',3,27,null,null,null,''granada'');

  insert into aptitud values (''e0'' ,3,1,0,3,1,5,4,0,null,null,null);
  insert into aptitud values (''e1'' ,3,1,0,3,1,3,4,0,null,null,null);
  insert into aptitud values (''e2'' ,3,1,2,3,1,1,4,1,null,null,null);
  insert into aptitud values (''e3'' ,3,1,2,3,1,3,3,3,null,null,null);
  insert into aptitud values (''e4'' ,3,1,1,3,1,5,3,20,null,null,null);
  insert into aptitud values (''e5'' ,3,1,1,3,1,5,3,5,null,null,null);
  insert into aptitud values (''e6'' ,3,1,0,3,1,4,0,23,null,null,null);
  insert into aptitud values (''e7'' ,3,1,3,3,1,0,4,3,null,null,null);
  insert into aptitud values (''e8'' ,3,1,1,3,1,5,3,1,null,null,null);
  insert into aptitud values (''e9'' ,3,1,1,3,1,3,6,2,0,4,2);
  insert into aptitud values (''e10'',3,1,1,3,1,4,4,1,null,null,null);
  insert into aptitud values (''e11'',3,1,2,3,1,0,4,3,null,null,null);
  insert into aptitud values (''e12'',3,1,2,3,1,1,3,20,null,null,null);
  insert into aptitud values (''e13'',3,1,3,3,1,0,3,15,null,null,null);
  insert into aptitud values (''e14'',3,1,1,3,1,4,6,3,1,5,2);
  insert into aptitud values (''e15'',3,1,2,3,1,1,7,2,4,-4,17);
  insert into aptitud values (''e16'',3,1,1,3,1,3,4,3,null,null,null);
  insert into aptitud values (''e17'',3,1,2,3,1,1,3,7,null,null,null);
  insert into aptitud values (''e18'',3,1,2,3,1,2,3,4,null,null,null);
  insert into aptitud values (''e19'',3,1,1,3,1,5,4,1,null,null,null);
  insert into aptitud values (''e20'',3,1,2,3,1,2,4,4,null,null,null);
  insert into aptitud values (''e21'',3,1,2,3,1,2,4,3,null,null,null);
  insert into aptitud values (''e22'',3,1,0,3,1,4,5,15,null,null,20);
  insert into aptitud values (''e23'',3,1,0,3,1,4,4,2,null,null,null);
  insert into aptitud values (''e24'',3,1,0,3,1,4,6,15,13,17,2);

  insert into dpto values (''d0'',''exportacion'',''madrid'',35000000);
  insert into dpto values (''d1'',''centro''     ,''madrid'',30000000);
  insert into dpto values (''d2'',''sur''        ,''malaga'',40000000);
  insert into dpto values (''d3'',''norte''   ,''barcelona'',35000000);
  insert into dpto values (''d4'',''levante''  ,''valencia'',10000000);

  insert into puestos values (''p0'',''director'' ,3,1,2,3,1,0,4,4,null ,null,null);
  insert into puestos values (''p1'',''ingeniero'',3,1,2,3,1,1,4,3,null ,null,null);
  insert into puestos values (''p2'',''tecnico''  ,3,1,2,3,1,2,4,3,null ,null,null);
  insert into puestos values (''p3'',''administrativo'',3,1,1,3,1,3,4,0 ,null,null,null);
  insert into puestos values (''p4'',''secretario'',3,1,1,3,1,4,4,1,null,null,null);
  insert into puestos values (''p5'',''vendedor''  ,3,1,0,3,1,5,4,2,null,null,null);
  insert into puestos values (''p6'',''vendedor aux1'',3,1,0,3,1,5,3,0,null,null,null);
  insert into puestos values (''p7'',''vendedor aux2'',3,1,0,3,1,5,0,null,null,null,null);
  insert into puestos values (''p8'',''vendedor aux3'',3,1,0,3,1,5,1,null,null,null,null);
  insert into puestos values (''p9'',''vendedor aux4'',3,1,0,3,1,5,2,null,null,null,null);

  insert into empleos values (''e0'' ,''d1'',''p5'', 60000,3,10000,null,null,null,3,1,1);
  insert into empleos values (''e1'' ,''d1'',''p3'', 80000,3,5000,null,null,null,3,1,2);
  insert into empleos values (''e2'' ,''d3'',''p1'',200000,4,2,null,null,null,3,1,2);
  insert into empleos values (''e3'' ,''d4'',''p3'',120000,3,10000,null,null,null,3,1,2);
  insert into empleos values (''e4'' ,''d0'',''p5'',160000,4,3,null,null,null,3,1,3);
  insert into empleos values (''e5'' ,''d2'',''p5'',140000,3,30000,null,null,null,3,1,2);
  insert into empleos values (''e6'' ,''d0'',''p4'',120000,4,0,null,null,null,3,1,1);
  insert into empleos values (''e7'' ,''d0'',''p0'',500000,4,4,null,null,null,3,1,3);
  insert into empleos values (''e8'' ,''d2'',''p5'', 90000,3,35000,null,null,null,3,1,2);
  insert into empleos values (''e9'' ,''d1'',''p3'',120000,6,5000,0,10000,5000,3,1,2);
  insert into empleos values (''e10'',''d3'',''p4'',110000,4,1,null,null,null,3,1,2);
  insert into empleos values (''e11'',''d1'',''p0'',450000,4,4,null,null,null,3,1,2);
  insert into empleos values (''e12'',''d3'',''p1'',350000,3,40000,null,null,null,3,1,2);
  insert into empleos values (''e13'',''d4'',''p0'',475000,3,50000,null,null,null,3,1,2);
  insert into empleos values (''e14'',''d3'',''p4'',100000,4,1,null,null,null,3,1,2);
  insert into empleos values (''e15'',''d2'',''p1'',230000,7,50000,10000,-15000,100000,3,1,2);
  insert into empleos values (''e16'',''d1'',''p3'',170000,4,2,null,null,null,3,1,3);
  insert into empleos values (''e17'',''d3'',''p1'',180000,4,0,null,null,null,3,1,0);
  insert into empleos values (''e18'',''d2'',''p2'',160000,3,20000,null,null,null,3,1,2);
  insert into empleos values (''e19'',''d2'',''p5'',130000,4,3,null,null,null,3,1,3);
  insert into empleos values (''e20'',''d0'',''p2'',230000,4,2,null,null,null,3,1,2);
  insert into empleos values (''e21'',''d3'',''p2'',270000,6,25000,20000,30000,5000,3,1,2);
  insert into empleos values (''e22'',''d1'',''p4'', 85000,4,1,null,null,null,3,1,2);

  insert into ciudades values (''barcelona'',''madrid''  ,621);
  insert into ciudades values (''barcelona'',''malaga''  ,995);
  insert into ciudades values (''barcelona'',''granada'' ,875);
  insert into ciudades values (''barcelona'',''valencia'',352);
  insert into ciudades values (''barcelona'',''roma'',1466);
  insert into ciudades values (''madrid''   ,''malaga''  ,542);
  insert into ciudades values (''madrid''   ,''granada'' ,432);
  insert into ciudades values (''madrid''   ,''valencia'',350);
  insert into ciudades values (''madrid''   ,''marsella'',1200);
  insert into ciudades values (''malaga''   ,''granada'' ,128);
  insert into ciudades values (''malaga''   ,''valencia'',643);
  insert into ciudades values (''malaga''   ,''paris'',1830);
  insert into ciudades values (''granada''  ,''valencia'',528);
  insert into ciudades values (''granada''  ,''almeria'',175);
  insert into ciudades values (''granada''  ,''pontevedra'',1057);
  insert into ciudades values (''granada''  ,''santa fe'',6);

  insert into requisitos values (0,0,null,null,null,null,null,null,null,null); -- unknown
  insert into requisitos values (1,1,null,null,null,null,null,null,null,null); -- undefined
  insert into requisitos values (2,2,null,null,null,null,null,null,null,null); -- null
  insert into requisitos values (3,3,1,0,null,null,null,null,null,null); -- 1/secundaria(label)
  insert into requisitos values (4,3,1,1,null,null,null,null,null,null); -- 1/diplomado
  insert into requisitos values (5,3,1,2,null,null,null,null,null,null); -- 1/licenciado
  insert into requisitos values (6,3,.9,3,null,null,null,null,null,null);-- .9/doctor
  insert into requisitos values (7,4,.7,2,null,null,null,null,null,null);-- .7/licenciado     
  insert into requisitos values (8,4,.2,0,.6,1,1,2,.8,3);-- .2/sec.,.6/dip.,1/lic.,.8/doctor
  insert into requisitos values (9,4,.4,1,.7,2,.9,3,null,null); -- .4/dip.,.7/lic.,.9/doctor
  return 0;
  commit;
end;
'language 'plpgsql';


-- mensaje de fin:
\echo  ('>>>>');
\echo  ('>>>> fin de la instalacion: si existieron errores, revise su texto.');
\echo  ('>>>>');

select ejemplo();
